body{
background-color:black;
color:white;
text-align:left;
vertical-align:top;
font-family:verdana, sans-serif;
}
td.folderOpen{
background-image:url('/style/bw/html-menu-treeview/folderOpen.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
height:20px;
vertical-align:top;
}
td.folderClosed{
background-image:url('/style/bw/html-menu-treeview/folderClosed.gif');
background-repeat:no-repeat;
cursor:pointer;
padding-left:20px;
font-size:14px;
vertical-align:top;
}
td.minusNode{
background-image:url('/style/bw/html-menu-treeview/minusNode.gif');
cursor:pointer;    
}
td.lastMinusNode{
background-image:url('/style/bw/html-menu-treeview/lastMinusNode.gif');
cursor:pointer;    
}
td.plusNode{
background-image:url('/style/bw/html-menu-treeview/plusNode.gif');
cursor:pointer;    
}
td.lastPlusNode{
background-image:url('/style/bw/html-menu-treeview/lastPlusNode.gif');
cursor:pointer;    
}
td.node{
background-image:url('/style/bw/html-menu-treeview/node.gif');
cursor:pointer;
font-size:14px;
height:20px;

}
td.submenuDeco{
background-image:url('/style/bw/html-menu-treeview/vertLine.gif');
background-repeat:repeat-y;
}
td.lastNode{
background-image:url('/style/bw/html-menu-treeview/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:14px;
height:20px;
}
a.treeviewLink{
font-size:14px;
height:20px;
color:white;
}
a.treeviewLink:hover{
font-size:14px;
height:20px;
color:red;
}
