folderClosed = new Image(16,16);
folderClosed.src='/style/simple/16/html-menu-treeview/folderClosed.gif';
plusNode = new Image(16,16);
plusNode.src='/style/simple/16/html-menu-treeview/plusNode.gif';
lastPlusNode = new Image(16,16);
lastPlusNode.src='/style/simple/16/html-menu-treeview/lastPlusNode.gif';
clasicPlusNode = new Image(16,16);
clasicPlusNode.src='/style/simple/16/html-menu-treeview/clasicPlusNode.gif';
clasicLastPlusNode = new Image(16,16);
clasicLastPlusNode.src='/style/simple/16/html-menu-treeview/clasicLastPlusNode.gif';
